@@ -1,16 +1,18 @@
-#   Copyright 2019 AUI, Inc. Washington DC, USA
+#  CASA Next Generation Infrastructure
+#  Copyright (C) 2021 AUI, Inc. Washington DC, USA
 #
-#   Licensed under the Apache License, Version 2.0 (the "License");
-#   you may not use this file except in compliance with the License.
-#   You may obtain a copy of the License at
+#  This program is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
 #
-#       http://www.apache.org/licenses/LICENSE-2.0
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
 #
-#   Unless required by applicable law or agreed to in writing, software
-#   distributed under the License is distributed on an "AS IS" BASIS,
-#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#   See the License for the specific language governing permissions and
-#   limitations under the License.
+#  You should have received a copy of the GNU General Public License
+#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 this module will be included in the api
 """
@@ -50,7 +52,7 @@ def region(xds, name='REGION1', ra=None, dec=None, pixels=None, pol=-1, channels
     if not name.strip(): name = 'REGIONX'
     if ra is None: ra=[0.0, 0.0]
     if dec is None: dec=[0.0, 0.0]
-    if pixels is None: pixels = np.zeros((1,2), dtype=int)-1
+    if pixels is None: pixels = np.zeros((1,2), dtype=int)
     pixels = np.array(pixels, dtype=int)
     if (pixels.ndim != 2) or (pixels.shape[1] != 2):
       print('ERROR: pixels parameter not a (N,2) array')
@@ -79,10 +81,10 @@ def region(xds, name='REGION1', ra=None, dec=None, pixels=None, pol=-1, channels
     # OR pixel values with ra/dec values
     #region = region | xr.ones_like(xds.IMAGE,dtype=bool).where(xds.d0.isin(pixels[:,0]) &
     #                                                           xds.d1.isin(pixels[:,1]), False)
-    region = region | xr.ones_like(xds.IMAGE,dtype=bool).where((xds.l > np.min(pixels[:,0])) &
-                                                               (xds.l < np.max(pixels[:,0])) &
-                                                               (xds.m > np.min(pixels[:,1])) &
-                                                               (xds.m < np.max(pixels[:,1])), False)
+    region = region | xr.ones_like(xds.IMAGE,dtype=bool).where((xds.l > xds.l[np.min(pixels[:,0]):np.max(pixels[:,0])+1].min()) &
+                                                               (xds.l < xds.l[np.min(pixels[:,0]):np.max(pixels[:,0])+1].max()) &
+                                                               (xds.m > xds.m[np.min(pixels[:,1]):np.max(pixels[:,1])+1].min()) &
+                                                               (xds.m < xds.m[np.min(pixels[:,1]):np.max(pixels[:,1])+1].max()), False)
     
     # apply polarization and channels selections
     region = region.where(xds.pol.isin(xds.pol[pol]), False)
